pub struct exactInputSingleCall {
pub params: <ExactInputSingleParams as SolType>::RustType,
}Expand description
Function with signature exactInputSingle((address,address,int24,address,uint256,uint256,uint256,uint160)) and selector 0xa026383e.
function exactInputSingle(ExactInputSingleParams params) external payable returns (uint256 amountOut);Fields
params: <ExactInputSingleParams as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for exactInputSingleCall
impl Clone for exactInputSingleCall
Sourcefn clone(&self) -> exactInputSingleCall
fn clone(&self) -> exactInputSingleCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for exactInputSingleCall
impl SolCall for exactInputSingleCall
Sourceconst SIGNATURE: &'static str = "exactInputSingle((address,address,int24,address,uint256,uint256,uint256,uint160))"
const SIGNATURE: &'static str = "exactInputSingle((address,address,int24,address,uint256,uint256,uint256,uint160))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (ExactInputSingleParams,)
type Parameters<'a> = (ExactInputSingleParams,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<exactInputSingleCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<exactInputSingleCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<256>,)
type ReturnTuple<'a> = (Uint<256>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<exactInputSingleCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<exactInputSingleCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<exactInputSingleCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> exactInputSingleCall
fn new<'a>( tuple: <<exactInputSingleCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> exactInputSingleCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <exactInputSingleCall as SolCall>::Token<'_>
fn tokenize(&self) -> <exactInputSingleCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<exactInputSingleCall as SolCall>::Return,
) -> <exactInputSingleCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<exactInputSingleCall as SolCall>::Return, ) -> <exactInputSingleCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<exactInputSingleCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<exactInputSingleCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<exactInputSingleCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<exactInputSingleCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.