pub struct collectCall {
pub params: <CollectParams as SolType>::RustType,
}Expand description
Function with signature collect((uint256,address,uint128,uint128)) and selector 0xfc6f7865.
function collect(CollectParams params) external payable returns (uint256 amount0, uint256 amount1);Fields
params: <CollectParams as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for collectCall
impl Clone for collectCall
Sourcefn clone(&self) -> collectCall
fn clone(&self) -> collectCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for collectCall
impl SolCall for collectCall
Sourceconst SIGNATURE: &'static str = "collect((uint256,address,uint128,uint128))"
const SIGNATURE: &'static str = "collect((uint256,address,uint128,uint128))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (CollectParams,)
type Parameters<'a> = (CollectParams,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<collectCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<collectCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = collectReturn
type Return = collectReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Uint<256>, Uint<256>)
type ReturnTuple<'a> = (Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<collectCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<collectCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<collectCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> collectCall
fn new<'a>( tuple: <<collectCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> collectCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<collectCall as SolCall>::Return,
) -> <collectCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<collectCall as SolCall>::Return, ) -> <collectCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<collectCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<collectCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<collectCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<collectCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.