pub struct increaseLiquidityCall {
pub params: <IncreaseLiquidityParams as SolType>::RustType,
}Expand description
Function with signature increaseLiquidity((uint256,uint256,uint256,uint256,uint256,uint256)) and selector 0x219f5d17.
function increaseLiquidity(IncreaseLiquidityParams params) external payable returns (uint128 liquidity, uint256 amount0, uint256 amount1);Fields
params: <IncreaseLiquidityParams as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for increaseLiquidityCall
impl Clone for increaseLiquidityCall
Sourcefn clone(&self) -> increaseLiquidityCall
fn clone(&self) -> increaseLiquidityCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for increaseLiquidityCall
impl SolCall for increaseLiquidityCall
Sourceconst SIGNATURE: &'static str = "increaseLiquidity((uint256,uint256,uint256,uint256,uint256,uint256))"
const SIGNATURE: &'static str = "increaseLiquidity((uint256,uint256,uint256,uint256,uint256,uint256))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (IncreaseLiquidityParams,)
type Parameters<'a> = (IncreaseLiquidityParams,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<increaseLiquidityCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<increaseLiquidityCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = increaseLiquidityReturn
type Return = increaseLiquidityReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Uint<128>, Uint<256>, Uint<256>)
type ReturnTuple<'a> = (Uint<128>, Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<increaseLiquidityCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<increaseLiquidityCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<increaseLiquidityCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> increaseLiquidityCall
fn new<'a>( tuple: <<increaseLiquidityCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> increaseLiquidityCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <increaseLiquidityCall as SolCall>::Token<'_>
fn tokenize(&self) -> <increaseLiquidityCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<increaseLiquidityCall as SolCall>::Return,
) -> <increaseLiquidityCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<increaseLiquidityCall as SolCall>::Return, ) -> <increaseLiquidityCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<increaseLiquidityCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<increaseLiquidityCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<increaseLiquidityCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<increaseLiquidityCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.