pub struct mintCall {
pub params: <ShadowMintParams as SolType>::RustType,
}Expand description
Function with signature mint((address,address,int24,int24,int24,uint256,uint256,uint256,uint256,address,uint256)) and selector 0x6d70c415.
function mint(ShadowMintParams params) external payable returns (uint256 tokenId, uint128 liquidity, uint256 amount0, uint256 amount1);Fields
params: <ShadowMintParams as SolType>::RustTypeTrait Implementations
Sourceimpl SolCall for mintCall
impl SolCall for mintCall
Sourceconst SIGNATURE: &'static str = "mint((address,address,int24,int24,int24,uint256,uint256,uint256,uint256,address,uint256))"
const SIGNATURE: &'static str = "mint((address,address,int24,int24,int24,uint256,uint256,uint256,uint256,address,uint256))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (ShadowMintParams,)
type Parameters<'a> = (ShadowMintParams,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<mintCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<mintCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<256>, Uint<128>, Uint<256>, Uint<256>)
type ReturnTuple<'a> = (Uint<256>, Uint<128>, Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<mintCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<mintCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<mintCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> mintCall
fn new<'a>( tuple: <<mintCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> mintCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<mintCall as SolCall>::Return,
) -> <mintCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<mintCall as SolCall>::Return, ) -> <mintCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<mintCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<mintCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<mintCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<mintCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.